.. _code-reviews-with-gerrit:

Code Reviews with Gerrit
========================

Manila uses the `Gerrit`_ tool to review proposed code changes. The review site
is https://review.opendev.org.

Gerrit is a complete replacement for Github pull requests. `All Github pull
requests to the manila repository will be ignored`.

See the `Development Workflow`_ for more detailed documentation on how
to work with Gerrit.

.. _Gerrit: http://code.google.com/p/gerrit
.. _Development Workflow: https://docs.openstack.org/infra/manual/developers.html#development-workflow
